bayespy.inference.vmp.transformations.RotateSwitchingMarkovChain.rotate
=======================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateSwitchingMarkovChain.rotate